package Net::Async::Slack::Event::DndUpdated;

use strict;
use warnings;

our $VERSION = '0.003'; # VERSION

use Net::Async::Slack::EventType;

=head1 NAME

Net::Async::Slack::Event::DndUpdated - Do not Disturb settings changed for the current user

=head1 DESCRIPTION

Example input data:

    dnd:read

=cut

sub type { 'dnd_updated' }

1;

__END__

=head1 AUTHOR

Tom Molesworth <TEAM@cpan.org>

=head1 LICENSE

Copyright Tom Molesworth 2016-2019. Licensed under the same terms as Perl itself.
